@@ -1,9 +1,8 @@
 import json
-from typing import Any, Union
+from typing import Annotated, Any, Union
 
 import pytest
 from pydantic_core import PydanticCustomError, PydanticSerializationError, Url
-from typing_extensions import Annotated
 
 from pydantic import (
     AfterValidator,
@@ -125,10 +124,13 @@ def test_any_url_success(value):
     [
         ('http:///', 'url_parsing', 'Input should be a valid URL, empty host'),
         ('http://??', 'url_parsing', 'Input should be a valid URL, empty host'),
-        (
+        pytest.param(
             'https://example.org more',
             'url_parsing',
-            'Input should be a valid URL, invalid domain character',
+            'Input should be a valid URL, invalid international domain name',
+            marks=pytest.mark.skip(
+                reason='Skipping until pydantic-core version with url validation updates is available'
+            ),
         ),
         ('$https://example.org', 'url_parsing', 'Input should be a valid URL, relative URL without a base'),
         ('../icons/logo.gif', 'url_parsing', 'Input should be a valid URL, relative URL without a base'),
@@ -531,6 +533,10 @@ def test_mariadb_dsns(dsn):
     [
         'clickhouse+native://user:pass@localhost:9000/app',
         'clickhouse+asynch://user:pass@localhost:9000/app',
+        'clickhouse+http://user:pass@localhost:9000/app',
+        'clickhouse://user:pass@localhost:9000/app',
+        'clickhouses://user:pass@localhost:9000/app',
+        'clickhousedb://user:pass@localhost:9000/app',
     ],
 )
 def test_clickhouse_dsns(dsn):
@@ -761,8 +767,7 @@ def test_mongodb_dsns():
             'mongodb+srv://user:pass@localhost/app',
             marks=pytest.mark.xfail(
                 reason=(
-                    'This case is not supported. '
-                    'Check https://github.com/pydantic/pydantic/pull/7116 for more details.'
+                    'This case is not supported. Check https://github.com/pydantic/pydantic/pull/7116 for more details.'
                 )
             ),
         ),
@@ -985,7 +990,7 @@ def test_email_validator_not_installed(mocker):
 
 def test_import_email_validator_not_installed(mocker):
     mocker.patch.dict('sys.modules', {'email_validator': None})
-    with pytest.raises(ImportError, match=r'email-validator is not installed, run `pip install pydantic\[email\]`'):
+    with pytest.raises(ImportError, match=r'email-validator is not installed, run `pip install \'pydantic\[email\]\'`'):
         import_email_validator()
 
 
@@ -1057,6 +1062,8 @@ def test_specialized_urls() -> None:
     assert http_url2.path == '/something'
     assert http_url2.username is None
     assert http_url2.password is None
+    assert http_url.encoded_string() == 'http://example.com/something'
+    assert http_url2.encoded_string() == 'http://example.com/something'
 
 
 def test_url_equality() -> None:
@@ -1067,6 +1074,14 @@ def test_url_equality() -> None:
     )
 
 
+def test_encode_multi_host_url() -> None:
+    multi_host_url_postgres = PostgresDsn('postgres://user:pass@localhost:5432/app')
+    multi_host_url_http_url = HttpUrl('http://example.com/something')
+
+    assert multi_host_url_postgres.encoded_string() == 'postgres://user:pass@localhost:5432/app'
+    assert multi_host_url_http_url.encoded_string() == 'http://example.com/something'
+
+
 def test_equality_independent_of_init() -> None:
     ta = TypeAdapter(HttpUrl)
     from_str = ta.validate_python('http://example.com/something')
@@ -1201,3 +1216,17 @@ def test_url_ser_as_any() -> None:
     ta = TypeAdapter(Any)
     assert ta.dump_python(HttpUrl('http://example.com')) == HttpUrl('http://example.com')
     assert ta.dump_json(HttpUrl('http://example.com')) == b'"http://example.com/"'
+
+
+@pytest.mark.parametrize(
+    'type',
+    [Url, AnyUrl, HttpUrl],
+)
+def test_url_preserve_empty_path(type) -> None:
+    ta_config = TypeAdapter(type, config={'url_preserve_empty_path': True})
+
+    assert str(ta_config.validate_python('http://example.com')) == 'http://example.com'
+
+    ta_constraint = TypeAdapter(Annotated[type, UrlConstraints(preserve_empty_path=True)])
+
+    assert str(ta_constraint.validate_python('http://example.com')) == 'http://example.com'
